==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_vulkan_queue.js <==
var class_ogre_1_1_vulkan_queue =
[
    [ "PerFrameData", "struct_ogre_1_1_vulkan_queue_1_1_per_frame_data.html", "struct_ogre_1_1_vulkan_queue_1_1_per_frame_data" ],
    [ "EncoderState", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2f", [
      [ "EncoderGraphicsOpen", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fa356b02e1af6bb0a25c686ad4c03e35e1", null ],
      [ "EncoderComputeOpen", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fae90ea87b44cc5ef96a70d7c34b8bc820", null ],
      [ "EncoderCopyOpen", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fac87ee43354bf148691669cc89973cd1c", null ],
      [ "EncoderClosed", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fa12d1c6e5f2d52bdfdd63a4f428cf13b5", null ]
    ] ],
    [ "QueueFamily", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925", [
      [ "Graphics", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925a08550487bb6e94af4c6299bdaa6e915a", null ],
      [ "Compute", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925a1189aa253ffb3db870cb4b43244f6dd6", null ],
      [ "Transfer", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925a7dbb4d3d8f80c29d4d618ed8925bfafe", null ],
      [ "NumQueueFamilies", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925ac44b72f90a5b05fcb30d52ff91139367", null ]
    ] ],
    [ "VulkanQueue", "class_ogre_1_1_vulkan_queue.html#acb9176b20137787e5be3ad7eff05c98a", null ],
    [ "~VulkanQueue", "class_ogre_1_1_vulkan_queue.html#a841750a1e1aed92cc0f72824acb2acc1", null ],
    [ "_isFrameFinished", "class_ogre_1_1_vulkan_queue.html#a49123a1e10f54e9351bd2734b748db3e", null ],
    [ "_waitOnFrame", "class_ogre_1_1_vulkan_queue.html#a662c9b12120c0ae31d2c70f81ad2a662", null ],
    [ "acquireCurrentFence", "class_ogre_1_1_vulkan_queue.html#a6d98adf0e77422486abfda11278b8192", null ],
    [ "addWindowToWaitFor", "class_ogre_1_1_vulkan_queue.html#abf300b7468504086cd219492e596f5cc", null ],
    [ "commitAndNextCommandBuffer", "class_ogre_1_1_vulkan_queue.html#a8ab7d4343e87b2eae286dd7a95e63b4a", null ],
    [ "destroy", "class_ogre_1_1_vulkan_queue.html#acff136e6dd1e37c490b2074fc45116da", null ],
    [ "endAllEncoders", "class_ogre_1_1_vulkan_queue.html#afa4bed67c51db1073c5caa660c71f54e", null ],
    [ "endComputeEncoder", "class_ogre_1_1_vulkan_queue.html#a4e9b44d89551657216c177753115e008", null ],
    [ "endCopyEncoder", "class_ogre_1_1_vulkan_queue.html#a31b6f4bb8e0b2c08829b669836b802d1", null ],
    [ "endRenderEncoder", "class_ogre_1_1_vulkan_queue.html#add80ec09a31bed7221ce55a639eea902", null ],
    [ "getComputeEncoder", "class_ogre_1_1_vulkan_queue.html#a47eda4ae6f4e45efd7c4cc1c153657c4", null ],
    [ "getCopyEncoder", "class_ogre_1_1_vulkan_queue.html#a036b99841e3865ee04bd05f624fd97c5", null ],
    [ "getCopyEncoderV1Buffer", "class_ogre_1_1_vulkan_queue.html#affa78f52be9822ce962cdc65875edd10", null ],
    [ "getEncoderState", "class_ogre_1_1_vulkan_queue.html#ab0e5dbece414e38e74c3a149d71f0ac6", null ],
    [ "getFamilyIdx", "class_ogre_1_1_vulkan_queue.html#a424e609f3f750db0c72ad16fb36d3af3", null ],
    [ "getGraphicsEncoder", "class_ogre_1_1_vulkan_queue.html#a93cebbd4a1a54250d8438004ff292232", null ],
    [ "getVaoManager", "class_ogre_1_1_vulkan_queue.html#a6b73ca844c74f78b8bc9a7ca32daacf6", null ],
    [ "init", "class_ogre_1_1_vulkan_queue.html#af5430e25473c2c56f7add128096f83f6", null ],
    [ "isFenceFlushed", "class_ogre_1_1_vulkan_queue.html#aa81e74a7a7bf8ca155e3db8d944c9e27", null ],
    [ "notifyTextureDestroyed", "class_ogre_1_1_vulkan_queue.html#aa2744c3b250b6973b7a6c61dc230ffc2", null ],
    [ "releaseFence", "class_ogre_1_1_vulkan_queue.html#a02cfbf4a11ef5ecf3a8778b69c525660", null ],
    [ "setExternalQueue", "class_ogre_1_1_vulkan_queue.html#a3a960d1477ee79cf6fdb98fde9d00fff", null ],
    [ "setQueueData", "class_ogre_1_1_vulkan_queue.html#aae7866bee8f06b6dec53a33364a8934c", null ],
    [ "mCurrentCmdBuffer", "class_ogre_1_1_vulkan_queue.html#ad22ea4969d6b297d83e1af3c954c9c6f", null ],
    [ "mDevice", "class_ogre_1_1_vulkan_queue.html#a8248a57438f2e4fdb31151f61257988f", null ],
    [ "mFamily", "class_ogre_1_1_vulkan_queue.html#a637a41330cc77495c52c490747364c4b", null ],
    [ "mFamilyIdx", "class_ogre_1_1_vulkan_queue.html#ac3c4cb5a872736c0c15300e75d047995", null ],
    [ "mOwnerDevice", "class_ogre_1_1_vulkan_queue.html#a77dea2f32c03d2e2b5a408ca80256471", null ],
    [ "mQueue", "class_ogre_1_1_vulkan_queue.html#a6218144526c7c733e9c2c6067193bd5e", null ],
    [ "mQueueIdx", "class_ogre_1_1_vulkan_queue.html#a7cfd51fac6b1ab3356c32cfa2992b475", null ],
    [ "mWindowsPendingSwap", "class_ogre_1_1_vulkan_queue.html#a91aa95835506d65fa451a4842d4bb1ff", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_vulkan_queue.js <==
var class_ogre_1_1_vulkan_queue =
[
    [ "PerFrameData", "struct_ogre_1_1_vulkan_queue_1_1_per_frame_data.html", "struct_ogre_1_1_vulkan_queue_1_1_per_frame_data" ],
    [ "EncoderState", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2f", [
      [ "EncoderGraphicsOpen", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fa356b02e1af6bb0a25c686ad4c03e35e1", null ],
      [ "EncoderComputeOpen", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fae90ea87b44cc5ef96a70d7c34b8bc820", null ],
      [ "EncoderCopyOpen", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fac87ee43354bf148691669cc89973cd1c", null ],
      [ "EncoderClosed", "class_ogre_1_1_vulkan_queue.html#a784887cb760d1d5548528e47a8806c2fa12d1c6e5f2d52bdfdd63a4f428cf13b5", null ]
    ] ],
    [ "QueueFamily", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925", [
      [ "Graphics", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925a08550487bb6e94af4c6299bdaa6e915a", null ],
      [ "Compute", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925a1189aa253ffb3db870cb4b43244f6dd6", null ],
      [ "Transfer", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925a7dbb4d3d8f80c29d4d618ed8925bfafe", null ],
      [ "NumQueueFamilies", "class_ogre_1_1_vulkan_queue.html#a467d51923bda10ff87b144d4327da925ac44b72f90a5b05fcb30d52ff91139367", null ]
    ] ],
    [ "VulkanQueue", "class_ogre_1_1_vulkan_queue.html#acb9176b20137787e5be3ad7eff05c98a", null ],
    [ "~VulkanQueue", "class_ogre_1_1_vulkan_queue.html#a841750a1e1aed92cc0f72824acb2acc1", null ],
    [ "_isFrameFinished", "class_ogre_1_1_vulkan_queue.html#a49123a1e10f54e9351bd2734b748db3e", null ],
    [ "_waitOnFrame", "class_ogre_1_1_vulkan_queue.html#a662c9b12120c0ae31d2c70f81ad2a662", null ],
    [ "acquireCurrentFence", "class_ogre_1_1_vulkan_queue.html#a124b289d45fe42933246053591cb14b5", null ],
    [ "addWindowToWaitFor", "class_ogre_1_1_vulkan_queue.html#abf300b7468504086cd219492e596f5cc", null ],
    [ "commitAndNextCommandBuffer", "class_ogre_1_1_vulkan_queue.html#a8ab7d4343e87b2eae286dd7a95e63b4a", null ],
    [ "destroy", "class_ogre_1_1_vulkan_queue.html#a83080901e29d36858a922aab3ea5ba79", null ],
    [ "endAllEncoders", "class_ogre_1_1_vulkan_queue.html#afa4bed67c51db1073c5caa660c71f54e", null ],
    [ "endComputeEncoder", "class_ogre_1_1_vulkan_queue.html#a426676e84f721803ab9f464a4f1c7e2c", null ],
    [ "endCopyEncoder", "class_ogre_1_1_vulkan_queue.html#a783260a8b3bf26930a0cbdb28eca008f", null ],
    [ "endRenderEncoder", "class_ogre_1_1_vulkan_queue.html#add80ec09a31bed7221ce55a639eea902", null ],
    [ "getComputeEncoder", "class_ogre_1_1_vulkan_queue.html#a606c100841cc1a5fd9d335e6b563dacd", null ],
    [ "getCopyEncoder", "class_ogre_1_1_vulkan_queue.html#a036b99841e3865ee04bd05f624fd97c5", null ],
    [ "getCopyEncoderAsyncTextureTicketUpload", "class_ogre_1_1_vulkan_queue.html#a56cf2386195d4fefc73f0cace3e873d0", null ],
    [ "getCopyEncoderV1Buffer", "class_ogre_1_1_vulkan_queue.html#affa78f52be9822ce962cdc65875edd10", null ],
    [ "getEncoderState", "class_ogre_1_1_vulkan_queue.html#a643ba4b203d2859598a0e483d4e4ca54", null ],
    [ "getFamilyIdx", "class_ogre_1_1_vulkan_queue.html#a424e609f3f750db0c72ad16fb36d3af3", null ],
    [ "getGraphicsEncoder", "class_ogre_1_1_vulkan_queue.html#abae5002a538f1bca9308dac2fd0af409", null ],
    [ "getVaoManager", "class_ogre_1_1_vulkan_queue.html#af6869cf963af52ffb366dc997b4ad168", null ],
    [ "init", "class_ogre_1_1_vulkan_queue.html#af5430e25473c2c56f7add128096f83f6", null ],
    [ "isFenceFlushed", "class_ogre_1_1_vulkan_queue.html#aa81e74a7a7bf8ca155e3db8d944c9e27", null ],
    [ "notifyTextureDestroyed", "class_ogre_1_1_vulkan_queue.html#aa2744c3b250b6973b7a6c61dc230ffc2", null ],
    [ "releaseFence", "class_ogre_1_1_vulkan_queue.html#a02cfbf4a11ef5ecf3a8778b69c525660", null ],
    [ "setExternalQueue", "class_ogre_1_1_vulkan_queue.html#a3a960d1477ee79cf6fdb98fde9d00fff", null ],
    [ "setQueueData", "class_ogre_1_1_vulkan_queue.html#aae7866bee8f06b6dec53a33364a8934c", null ],
    [ "mCurrentCmdBuffer", "class_ogre_1_1_vulkan_queue.html#ad22ea4969d6b297d83e1af3c954c9c6f", null ],
    [ "mDevice", "class_ogre_1_1_vulkan_queue.html#a8248a57438f2e4fdb31151f61257988f", null ],
    [ "mFamily", "class_ogre_1_1_vulkan_queue.html#a637a41330cc77495c52c490747364c4b", null ],
    [ "mFamilyIdx", "class_ogre_1_1_vulkan_queue.html#ac3c4cb5a872736c0c15300e75d047995", null ],
    [ "mOwnerDevice", "class_ogre_1_1_vulkan_queue.html#a77dea2f32c03d2e2b5a408ca80256471", null ],
    [ "mQueue", "class_ogre_1_1_vulkan_queue.html#a6218144526c7c733e9c2c6067193bd5e", null ],
    [ "mQueueIdx", "class_ogre_1_1_vulkan_queue.html#a7cfd51fac6b1ab3356c32cfa2992b475", null ],
    [ "mWindowsPendingSwap", "class_ogre_1_1_vulkan_queue.html#a91aa95835506d65fa451a4842d4bb1ff", null ]
];
